cell

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 27, 2024 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrTenantModel = errors.New("invalid tenant model")

Functions

This section is empty.

Types

type Cell

type Cell struct {
	Model map[string]interface{}
	// contains filtered or unexported fields
}

func Generate

func Generate(templateBody string) (*Cell, error)

func New

func New(id string) *Cell

func Read

func Read(r io.Reader) (*Cell, error)

func (*Cell) Patch

func (c *Cell) Patch(patch jsonpatch.Patch) (*Cell, error)

Patch applies a JSON patch to the model.

The function returns a new cell with the patched model and an error if the patch could not be applied. The current model is not modified.

func (*Cell) PrereleaseVersion

func (c *Cell) PrereleaseVersion() string

func (*Cell) TenantID

func (c *Cell) TenantID() string

func (*Cell) TenantModelFileName

func (c *Cell) TenantModelFileName() string

func (*Cell) ToString

func (c *Cell) ToString() (string, error)

func (*Cell) URL

func (c *Cell) URL() string

func (*Cell) Upgrade

func (c *Cell) Upgrade(version string)

func (*Cell) Version

func (c *Cell) Version() string

Jump to