Documentation
¶
Index ¶
- Variables
- type Cell
- func (c *Cell) Patch(patch jsonpatch.Patch) (*Cell, error)
- func (c *Cell) PrereleaseVersion() string
- func (c *Cell) TenantID() string
- func (c *Cell) TenantModelFileName() string
- func (c *Cell) ToString() (string, error)
- func (c *Cell) URL() string
- func (c *Cell) Upgrade(version string)
- func (c *Cell) Version() string
Constants ¶
This section is empty.
Variables ¶
var ErrTenantModel = errors.New("invalid tenant model")
Functions ¶
This section is empty.
Types ¶
type Cell ¶
type Cell struct {
Model map[string]interface{}
// contains filtered or unexported fields
}
func (*Cell) Patch ¶
Patch applies a JSON patch to the model.
The function returns a new cell with the patched model and an error if the patch could not be applied. The current model is not modified.
func (*Cell) PrereleaseVersion ¶
func (*Cell) TenantModelFileName ¶
Click to show internal directories.
Click to hide internal directories.